abacusai.pipeline — AbacusAI documentation

# `abacusai.pipeline`

## Module Contents

### Classes

`Pipeline` | A Pipeline For Steps.

class abacusai.pipeline.Pipeline(client, pipelineName=None, pipelineId=None, createdAt=None, pipelineVariableMappings=None, notebookId=None, steps={}, pipelineReferences={}, latestPipelineVersion={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A Pipeline For Steps.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - pipelineName (str) – The name of the pipeline this step is a part of.

    - pipelineId (str) – The reference to the pipeline this step belongs to.

    - createdAt (str) – The date and time which the pipeline was created.

    - pipelineVariableMappings (dict) – A description of the function variables into the pipeline.

    - notebookId (str) – The reference to the notebook this pipeline belongs to.

    - steps (PipelineStep) – A list of the pipeline steps attached to the pipeline.

    - pipelineReferences (PipelineReference) – A list of references from the pipeline to other objects

    - latestPipelineVersion (PipelineVersion) – The latest version of the pipeline.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict